==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/BuildSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildSpecFluent<A extends BuildSpecFluent<A>> extends Fluent<A>{
  public Long getCompletionDeadlineSeconds();
  public A withCompletionDeadlineSeconds(Long completionDeadlineSeconds);
  public Boolean hasCompletionDeadlineSeconds();
  public Boolean getMountTrustedCA();
  public A withMountTrustedCA(Boolean mountTrustedCA);
  public Boolean hasMountTrustedCA();
  public A addToNodeSelector(String key,String value);
  public A addToNodeSelector(Map<String,String> map);
  public A removeFromNodeSelector(String key);
  public A removeFromNodeSelector(Map<String,String> map);
  public Map<String,String> getNodeSelector();
  public <K,V>A withNodeSelector(Map<String,String> nodeSelector);
  public Boolean hasNodeSelector();
  
  /**
   * This method has been deprecated, please use method buildOutput instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildOutput getOutput();
  public BuildOutput buildOutput();
  public A withOutput(BuildOutput output);
  public Boolean hasOutput();
  public BuildSpecFluent.OutputNested<A> withNewOutput();
  public BuildSpecFluent.OutputNested<A> withNewOutputLike(BuildOutput item);
  public BuildSpecFluent.OutputNested<A> editOutput();
  public BuildSpecFluent.OutputNested<A> editOrNewOutput();
  public BuildSpecFluent.OutputNested<A> editOrNewOutputLike(BuildOutput item);
  
  /**
   * This method has been deprecated, please use method buildPostCommit instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildPostCommitSpec getPostCommit();
  public BuildPostCommitSpec buildPostCommit();
  public A withPostCommit(BuildPostCommitSpec postCommit);
  public Boolean hasPostCommit();
  public BuildSpecFluent.PostCommitNested<A> withNewPostCommit();
  public BuildSpecFluent.PostCommitNested<A> withNewPostCommitLike(BuildPostCommitSpec item);
  public BuildSpecFluent.PostCommitNested<A> editPostCommit();
  public BuildSpecFluent.PostCommitNested<A> editOrNewPostCommit();
  public BuildSpecFluent.PostCommitNested<A> editOrNewPostCommitLike(BuildPostCommitSpec item);
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceRequirements getResources();
  public ResourceRequirements buildResources();
  public A withResources(ResourceRequirements resources);
  public Boolean hasResources();
  public BuildSpecFluent.ResourcesNested<A> withNewResources();
  public BuildSpecFluent.ResourcesNested<A> withNewResourcesLike(ResourceRequirements item);
  public BuildSpecFluent.ResourcesNested<A> editResources();
  public BuildSpecFluent.ResourcesNested<A> editOrNewResources();
  public BuildSpecFluent.ResourcesNested<A> editOrNewResourcesLike(ResourceRequirements item);
  
  /**
   * This method has been deprecated, please use method buildRevision instead.
   * @return The buildable object.
   */
  @Deprecated
  public SourceRevision getRevision();
  public SourceRevision buildRevision();
  public A withRevision(SourceRevision revision);
  public Boolean hasRevision();
  public BuildSpecFluent.RevisionNested<A> withNewRevision();
  public BuildSpecFluent.RevisionNested<A> withNewRevisionLike(SourceRevision item);
  public BuildSpecFluent.RevisionNested<A> editRevision();
  public BuildSpecFluent.RevisionNested<A> editOrNewRevision();
  public BuildSpecFluent.RevisionNested<A> editOrNewRevisionLike(SourceRevision item);
  public String getServiceAccount();
  public A withServiceAccount(String serviceAccount);
  public Boolean hasServiceAccount();
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildSource getSource();
  public BuildSource buildSource();
  public A withSource(BuildSource source);
  public Boolean hasSource();
  public BuildSpecFluent.SourceNested<A> withNewSource();
  public BuildSpecFluent.SourceNested<A> withNewSourceLike(BuildSource item);
  public BuildSpecFluent.SourceNested<A> editSource();
  public BuildSpecFluent.SourceNested<A> editOrNewSource();
  public BuildSpecFluent.SourceNested<A> editOrNewSourceLike(BuildSource item);
  
  /**
   * This method has been deprecated, please use method buildStrategy instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildStrategy getStrategy();
  public BuildStrategy buildStrategy();
  public A withStrategy(BuildStrategy strategy);
  public Boolean hasStrategy();
  public BuildSpecFluent.StrategyNested<A> withNewStrategy();
  public BuildSpecFluent.StrategyNested<A> withNewStrategyLike(BuildStrategy item);
  public BuildSpecFluent.StrategyNested<A> editStrategy();
  public BuildSpecFluent.StrategyNested<A> editOrNewStrategy();
  public BuildSpecFluent.StrategyNested<A> editOrNewStrategyLike(BuildStrategy item);
  public A addToTriggeredBy(Integer index,BuildTriggerCause item);
  public A setToTriggeredBy(Integer index,BuildTriggerCause item);
  public A addToTriggeredBy(io.fabric8.openshift.api.model.BuildTriggerCause... items);
  public A addAllToTriggeredBy(Collection<BuildTriggerCause> items);
  public A removeFromTriggeredBy(io.fabric8.openshift.api.model.BuildTriggerCause... items);
  public A removeAllFromTriggeredBy(Collection<BuildTriggerCause> items);
  public A removeMatchingFromTriggeredBy(Predicate<BuildTriggerCauseBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTriggeredBy instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<BuildTriggerCause> getTriggeredBy();
  public List<BuildTriggerCause> buildTriggeredBy();
  public BuildTriggerCause buildTriggeredBy(Integer index);
  public BuildTriggerCause buildFirstTriggeredBy();
  public BuildTriggerCause buildLastTriggeredBy();
  public BuildTriggerCause buildMatchingTriggeredBy(Predicate<BuildTriggerCauseBuilder> predicate);
  public Boolean hasMatchingTriggeredBy(Predicate<BuildTriggerCauseBuilder> predicate);
  public A withTriggeredBy(List<BuildTriggerCause> triggeredBy);
  public A withTriggeredBy(io.fabric8.openshift.api.model.BuildTriggerCause... triggeredBy);
  public Boolean hasTriggeredBy();
  public BuildSpecFluent.TriggeredByNested<A> addNewTriggeredBy();
  public BuildSpecFluent.TriggeredByNested<A> addNewTriggeredByLike(BuildTriggerCause item);
  public BuildSpecFluent.TriggeredByNested<A> setNewTriggeredByLike(Integer index,BuildTriggerCause item);
  public BuildSpecFluent.TriggeredByNested<A> editTriggeredBy(Integer index);
  public BuildSpecFluent.TriggeredByNested<A> editFirstTriggeredBy();
  public BuildSpecFluent.TriggeredByNested<A> editLastTriggeredBy();
  public BuildSpecFluent.TriggeredByNested<A> editMatchingTriggeredBy(Predicate<BuildTriggerCauseBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withMountTrustedCA();
  public interface OutputNested<N> extends Nested<N>,BuildOutputFluent<BuildSpecFluent.OutputNested<N>>{
    public N and();
    public N endOutput();
    
  }
  public interface PostCommitNested<N> extends Nested<N>,BuildPostCommitSpecFluent<BuildSpecFluent.PostCommitNested<N>>{
    public N and();
    public N endPostCommit();
    
  }
  public interface ResourcesNested<N> extends Nested<N>,ResourceRequirementsFluent<BuildSpecFluent.ResourcesNested<N>>{
    public N and();
    public N endResources();
    
  }
  public interface RevisionNested<N> extends Nested<N>,SourceRevisionFluent<BuildSpecFluent.RevisionNested<N>>{
    public N and();
    public N endRevision();
    
  }
  public interface SourceNested<N> extends Nested<N>,BuildSourceFluent<BuildSpecFluent.SourceNested<N>>{
    public N and();
    public N endSource();
    
  }
  public interface StrategyNested<N> extends Nested<N>,BuildStrategyFluent<BuildSpecFluent.StrategyNested<N>>{
    public N and();
    public N endStrategy();
    
  }
  public interface TriggeredByNested<N> extends Nested<N>,BuildTriggerCauseFluent<BuildSpecFluent.TriggeredByNested<N>>{
    public N and();
    public N endTriggeredBy();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/BuildSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildSpecFluent<A extends BuildSpecFluent<A>> extends Fluent<A>{
  public Long getCompletionDeadlineSeconds();
  public A withCompletionDeadlineSeconds(Long completionDeadlineSeconds);
  public Boolean hasCompletionDeadlineSeconds();
  public Boolean getMountTrustedCA();
  public A withMountTrustedCA(Boolean mountTrustedCA);
  public Boolean hasMountTrustedCA();
  public A addToNodeSelector(String key,String value);
  public A addToNodeSelector(Map<String,String> map);
  public A removeFromNodeSelector(String key);
  public A removeFromNodeSelector(Map<String,String> map);
  public Map<String,String> getNodeSelector();
  public <K,V>A withNodeSelector(Map<String,String> nodeSelector);
  public Boolean hasNodeSelector();
  
  /**
   * This method has been deprecated, please use method buildOutput instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildOutput getOutput();
  public BuildOutput buildOutput();
  public A withOutput(BuildOutput output);
  public Boolean hasOutput();
  public BuildSpecFluent.OutputNested<A> withNewOutput();
  public BuildSpecFluent.OutputNested<A> withNewOutputLike(BuildOutput item);
  public BuildSpecFluent.OutputNested<A> editOutput();
  public BuildSpecFluent.OutputNested<A> editOrNewOutput();
  public BuildSpecFluent.OutputNested<A> editOrNewOutputLike(BuildOutput item);
  
  /**
   * This method has been deprecated, please use method buildPostCommit instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildPostCommitSpec getPostCommit();
  public BuildPostCommitSpec buildPostCommit();
  public A withPostCommit(BuildPostCommitSpec postCommit);
  public Boolean hasPostCommit();
  public BuildSpecFluent.PostCommitNested<A> withNewPostCommit();
  public BuildSpecFluent.PostCommitNested<A> withNewPostCommitLike(BuildPostCommitSpec item);
  public BuildSpecFluent.PostCommitNested<A> editPostCommit();
  public BuildSpecFluent.PostCommitNested<A> editOrNewPostCommit();
  public BuildSpecFluent.PostCommitNested<A> editOrNewPostCommitLike(BuildPostCommitSpec item);
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceRequirements getResources();
  public ResourceRequirements buildResources();
  public A withResources(ResourceRequirements resources);
  public Boolean hasResources();
  public BuildSpecFluent.ResourcesNested<A> withNewResources();
  public BuildSpecFluent.ResourcesNested<A> withNewResourcesLike(ResourceRequirements item);
  public BuildSpecFluent.ResourcesNested<A> editResources();
  public BuildSpecFluent.ResourcesNested<A> editOrNewResources();
  public BuildSpecFluent.ResourcesNested<A> editOrNewResourcesLike(ResourceRequirements item);
  
  /**
   * This method has been deprecated, please use method buildRevision instead.
   * @return The buildable object.
   */
  @Deprecated
  public SourceRevision getRevision();
  public SourceRevision buildRevision();
  public A withRevision(SourceRevision revision);
  public Boolean hasRevision();
  public BuildSpecFluent.RevisionNested<A> withNewRevision();
  public BuildSpecFluent.RevisionNested<A> withNewRevisionLike(SourceRevision item);
  public BuildSpecFluent.RevisionNested<A> editRevision();
  public BuildSpecFluent.RevisionNested<A> editOrNewRevision();
  public BuildSpecFluent.RevisionNested<A> editOrNewRevisionLike(SourceRevision item);
  public String getServiceAccount();
  public A withServiceAccount(String serviceAccount);
  public Boolean hasServiceAccount();
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildSource getSource();
  public BuildSource buildSource();
  public A withSource(BuildSource source);
  public Boolean hasSource();
  public BuildSpecFluent.SourceNested<A> withNewSource();
  public BuildSpecFluent.SourceNested<A> withNewSourceLike(BuildSource item);
  public BuildSpecFluent.SourceNested<A> editSource();
  public BuildSpecFluent.SourceNested<A> editOrNewSource();
  public BuildSpecFluent.SourceNested<A> editOrNewSourceLike(BuildSource item);
  
  /**
   * This method has been deprecated, please use method buildStrategy instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildStrategy getStrategy();
  public BuildStrategy buildStrategy();
  public A withStrategy(BuildStrategy strategy);
  public Boolean hasStrategy();
  public BuildSpecFluent.StrategyNested<A> withNewStrategy();
  public BuildSpecFluent.StrategyNested<A> withNewStrategyLike(BuildStrategy item);
  public BuildSpecFluent.StrategyNested<A> editStrategy();
  public BuildSpecFluent.StrategyNested<A> editOrNewStrategy();
  public BuildSpecFluent.StrategyNested<A> editOrNewStrategyLike(BuildStrategy item);
  public A addToTriggeredBy(int index,BuildTriggerCause item);
  public A setToTriggeredBy(int index,BuildTriggerCause item);
  public A addToTriggeredBy(io.fabric8.openshift.api.model.BuildTriggerCause... items);
  public A addAllToTriggeredBy(Collection<BuildTriggerCause> items);
  public A removeFromTriggeredBy(io.fabric8.openshift.api.model.BuildTriggerCause... items);
  public A removeAllFromTriggeredBy(Collection<BuildTriggerCause> items);
  public A removeMatchingFromTriggeredBy(Predicate<BuildTriggerCauseBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTriggeredBy instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<BuildTriggerCause> getTriggeredBy();
  public List<BuildTriggerCause> buildTriggeredBy();
  public BuildTriggerCause buildTriggeredBy(int index);
  public BuildTriggerCause buildFirstTriggeredBy();
  public BuildTriggerCause buildLastTriggeredBy();
  public BuildTriggerCause buildMatchingTriggeredBy(Predicate<BuildTriggerCauseBuilder> predicate);
  public Boolean hasMatchingTriggeredBy(Predicate<BuildTriggerCauseBuilder> predicate);
  public A withTriggeredBy(List<BuildTriggerCause> triggeredBy);
  public A withTriggeredBy(io.fabric8.openshift.api.model.BuildTriggerCause... triggeredBy);
  public Boolean hasTriggeredBy();
  public BuildSpecFluent.TriggeredByNested<A> addNewTriggeredBy();
  public BuildSpecFluent.TriggeredByNested<A> addNewTriggeredByLike(BuildTriggerCause item);
  public BuildSpecFluent.TriggeredByNested<A> setNewTriggeredByLike(int index,BuildTriggerCause item);
  public BuildSpecFluent.TriggeredByNested<A> editTriggeredBy(int index);
  public BuildSpecFluent.TriggeredByNested<A> editFirstTriggeredBy();
  public BuildSpecFluent.TriggeredByNested<A> editLastTriggeredBy();
  public BuildSpecFluent.TriggeredByNested<A> editMatchingTriggeredBy(Predicate<BuildTriggerCauseBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withMountTrustedCA();
  public interface OutputNested<N> extends Nested<N>,BuildOutputFluent<BuildSpecFluent.OutputNested<N>>{
    public N and();
    public N endOutput();
    
  }
  public interface PostCommitNested<N> extends Nested<N>,BuildPostCommitSpecFluent<BuildSpecFluent.PostCommitNested<N>>{
    public N and();
    public N endPostCommit();
    
  }
  public interface ResourcesNested<N> extends Nested<N>,ResourceRequirementsFluent<BuildSpecFluent.ResourcesNested<N>>{
    public N and();
    public N endResources();
    
  }
  public interface RevisionNested<N> extends Nested<N>,SourceRevisionFluent<BuildSpecFluent.RevisionNested<N>>{
    public N and();
    public N endRevision();
    
  }
  public interface SourceNested<N> extends Nested<N>,BuildSourceFluent<BuildSpecFluent.SourceNested<N>>{
    public N and();
    public N endSource();
    
  }
  public interface StrategyNested<N> extends Nested<N>,BuildStrategyFluent<BuildSpecFluent.StrategyNested<N>>{
    public N and();
    public N endStrategy();
    
  }
  public interface TriggeredByNested<N> extends Nested<N>,BuildTriggerCauseFluent<BuildSpecFluent.TriggeredByNested<N>>{
    public N and();
    public N endTriggeredBy();
    
  }
  
}
